==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Execution/checksd.py <==
#@ MODIF checksd Execution  DATE 28/11/2007   AUTEUR COURTOIS M.COURTOIS 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

"""
   Utilitaires pour tester la sd produite par une commande.
"""

from sets import Set

from Utilitai.Utmess import UTMESS

# pour utilisation dans eficas
try:
    import aster
except:
    pass


def get_list_objects():
    """Retourne la liste (Set) des objets jeveux prsents  un moment donn
    """
    return Set(aster.jeveux_getobjects(' '))


def check(checker, sd, l_before):
    """Vrifie la cohrence de la SD produite :
       - type des objets / ceux dclars dans le catalogue de la SD
       - prsence d'objets imprvus dans le catalogue
    l_before : liste des objets jeveux prsents avant la cration de la SD.
    """

    type_concept = type(sd).__name__
    if 0 : print "AJACOT checksd "+type_concept+" >"+sd.nomj.nomj+'<'

    # l_new = objets crs par la commande courante
    l_after = get_list_objects()
    l_new = l_after - l_before

    # on vrifie le contenu de la SD sur la base de son catalogue
    checker = sd.check(checker)

    # on imprime les messages d'erreur stocks dans le checker :
    lerreur=[]
    for level, obj, msg in checker.msg:
        if level == 0 : lerreur.append((obj,msg))
    lerreur.sort()
    if len(lerreur) > 0 :
        # pour "ouvrir" le message :
        UTMESS("E+", 'SDVERI_30')
        for obj, msg in lerreur :
            UTMESS("E+", 'SDVERI_31', valk=(obj, msg))

        # pour "fermer" le message :
        UTMESS("E", 'SDVERI_32')

    # on dtruit les messages dj imprims pour ne pas les rimprimer avec la SD suivante :
    checker.msg=[]

    # on vrifie que la commande n'a pas cr d'objets interdits
    l_possible = Set(checker.names.keys())
    l_interdit = list(l_new - l_possible)
    l_interdit.sort()
    if len(l_interdit) > 0 :
        # pour "ouvrir" le message :
        UTMESS("E+", 'SDVERI_40',valk=type_concept)
        for x in l_interdit :
            UTMESS('E+', 'SDVERI_41',valk=x)

        # pour "fermer" le message :
        UTMESS("E", 'SDVERI_42')

    return checker

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Execution/checksd.py <==
#@ MODIF checksd Execution  DATE 16/06/2008   AUTEUR PELLET J.PELLET 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ======================================================================

"""
   Utilitaires pour tester la sd produite par une commande.
"""

from sets import Set

from Utilitai.Utmess import UTMESS
from Noyau.asojb import OJB

# pour utilisation dans eficas
try:
    import aster
except:
    pass


def get_list_objects():
    """Retourne la liste (Set) des objets jeveux prsents  un moment donn
    """
    return Set(aster.jeveux_getobjects(' '))


def check(checker, sd, l_before, etape):
    """Vrifie la cohrence de la SD produite :
       - type des objets / ceux dclars dans le catalogue de la SD
       - prsence d'objets imprvus dans le catalogue
    l_before : liste des objets jeveux prsents avant la cration de la SD.
    """

    type_concept = type(sd).__name__
    if 0 : print "AJACOT checksd "+type_concept+" >"+sd.nomj.nomj+'<'

    # l_new = objets crs par la commande courante
    l_after = get_list_objects()
    l_new = l_after - l_before

    # on vrifie le contenu de la SD sur la base de son catalogue
    checker = sd.check(checker)

    # Vrification des "checksum":
    if 0 :  # A modifier (if 1) si l'on souhaite vrifier que les commandes ne
            # modifient pas leurs arguments "in" :
            # On vrifie que le "checksum" des objets qui existaient dj n'a pas chang:
            # Remarque : il faut bien le faire sur l_after car c'est checkSumOJB qui
            #             initialise la valeur pour les objets nouveaux
            for nom in l_after :
                if nom[0:1] == '&' : continue  #  cause des objets "&&SYS.*" et du cout des objets "&CATA.*"
                obj=OJB(nom)
                if etape.reuse :  # les commandes rentrantes ont le droit de modifier leur concept "reuse" :
                    if nom[0:8].strip() == sd.nomj.nomj.strip() :
                        checker.checkSumOJB(obj,sd,'maj')
                        continue
                checker.checkSumOJB(obj,sd)

    # on imprime les messages d'erreur stocks dans le checker :
    lerreur=[]
    for level, obj, msg in checker.msg:
        if level == 0 : lerreur.append((obj,msg))
    lerreur.sort()
    if len(lerreur) > 0 :
        # pour "ouvrir" le message :
        nom_concept=sd.nomj.nomj.strip()
        nom_commande=etape.definition.nom.strip()
        UTMESS("E+", 'SDVERI_30', valk=(nom_concept,nom_commande))
        for obj, msg in lerreur :
            UTMESS("E+", 'SDVERI_31', valk=(obj, msg))

        # pour "fermer" le message :
        UTMESS("E", 'SDVERI_32')

    # on dtruit les messages dj imprims pour ne pas les rimprimer avec la SD suivante :
    checker.msg=[]

    # on vrifie que la commande n'a pas cr d'objets interdits
    l_possible = Set(checker.names.keys())
    l_interdit = list(l_new - l_possible)
    l_interdit.sort()
    if len(l_interdit) > 0 :
        # pour "ouvrir" le message :
        UTMESS("E+", 'SDVERI_40',valk=type_concept)
        for x in l_interdit :
            UTMESS('E+', 'SDVERI_41',valk=x)

        # pour "fermer" le message :
        UTMESS("E", 'SDVERI_42')

    return checker
